@@ -1,6 +1,6 @@
 from jinja2 import Environment, BaseLoader, TemplateNotFound
 from typing import Dict, Any
-from xl_docx.compiler.processors import ComponentProcessor, StyleProcessor, DirectiveProcessor, \
+from xl_docx.compiler.processors import StyleProcessor, DirectiveProcessor, \
 TableProcessor, ParagraphProcessor, PagerProcessor
 
 
@@ -24,10 +24,8 @@ class XMLCompiler:
         r'))': '}}',
     }
     
-    def __init__(self, external_components_dir=None):
-        self.external_components_dir = external_components_dir
+    def __init__(self):
         self.processors = [
-            ComponentProcessor(external_components_dir),
             StyleProcessor(),
             DirectiveProcessor(), 
             TableProcessor(),
@@ -41,7 +39,8 @@ class XMLCompiler:
             lstrip_blocks=True
         )
 
-    def _convert_syntax(self, content: str) -> str:
+    @classmethod
+    def convert_syntax(cls, content: str) -> str:
         """转换自定义语法为Jinja2语法
         
         Args:
@@ -50,7 +49,7 @@ class XMLCompiler:
         Returns:
             str: 转换后的内容
         """
-        for custom, jinja in self.SYNTAX_MAP.items():
+        for custom, jinja in cls.SYNTAX_MAP.items():
             content = content.replace(custom, jinja)
         return content
 
@@ -61,7 +60,7 @@ class XMLCompiler:
                 template = processor.compile(template)
         
         # 在所有processor完成后进行语法转换
-        template = self._convert_syntax(template)
+        template = self.convert_syntax(template)
         
         return template
     
